@@ -23,6 +23,7 @@
 #include <pthread.h>
 #include <fcntl.h>
 #include <inttypes.h>
+#include <limits.h>
 
 #include "ring_rx.h"
 #include "ring_tx.h"
@@ -515,7 +516,7 @@ static void receive_to_xmit(struct ctx *ctx)
 			}
 
 			tpacket_hdr_clone(&hdr_out->tp_h, &hdr_in->tp_h);
-			fmemcpy(out, in, hdr_in->tp_h.tp_len);
+			memcpy(out, in, hdr_in->tp_h.tp_len);
 
 			kernel_may_pull_from_tx(&hdr_out->tp_h);
 			if (ctx->randomize)
@@ -660,7 +661,7 @@ static void read_pcap(struct ctx *ctx)
 			panic("Error prepare reading pcap!\n");
 	}
 
-	fmemset(&fm, 0, sizeof(fm));
+	memset(&fm, 0, sizeof(fm));
 
 	bpf_parse_rules(ctx->filter, &bpf_ops, ctx->link_type);
 	if (ctx->dump_bpf)
@@ -786,14 +787,14 @@ static void finish_multi_pcap_file(struct ctx *ctx, int fd)
 
 	close(fd);
 
-	fmemset(&itimer, 0, sizeof(itimer));
+	memset(&itimer, 0, sizeof(itimer));
 	setitimer(ITIMER_REAL, &itimer, NULL);
 }
 
 static int next_multi_pcap_file(struct ctx *ctx, int fd)
 {
 	int ret;
-	char fname[512];
+	char fname[PATH_MAX];
 	time_t ftime;
 
 	__pcap_io->fsync_pcap(fd);
@@ -843,7 +844,7 @@ static void reset_interval(struct ctx *ctx)
 static int begin_multi_pcap_file(struct ctx *ctx)
 {
 	int fd, ret;
-	char fname[256];
+	char fname[PATH_MAX];
 
 	bug_on(!__pcap_io);
 
@@ -887,6 +888,7 @@ static void finish_single_pcap_file(struct ctx *ctx, int fd)
 static int begin_single_pcap_file(struct ctx *ctx)
 {
 	int fd, ret;
+	char fname[PATH_MAX];
 
 	bug_on(!__pcap_io);
 
@@ -896,7 +898,20 @@ static int begin_single_pcap_file(struct ctx *ctx)
 		if (ctx->pcap == PCAP_OPS_MM)
 			ctx->pcap = PCAP_OPS_SG;
 	} else {
-		fd = open_or_die_m(ctx->device_out,
+		time_t t;
+		struct tm *ltm;
+
+		t = time(NULL);
+		if (t == -1)
+			panic("time() failed\n");
+
+		ltm = localtime(&t);
+		if (ltm == NULL)
+			panic("localtime() failed\n");
+
+		strftime(fname, sizeof(fname), ctx->device_out, ltm);
+
+		fd = open_or_die_m(fname,
 				   O_RDWR | O_CREAT | O_TRUNC |
 				   O_LARGEFILE, DEFFILEMODE);
 	}
